import logging
from rich.logging import RichHandler


def getRichLogger(
    name: str = "geemlib",
    level: str = "INFO",
    format: str = "%(message)s",
    datefmt: str = "[%X]",
    rich_tracebacks: bool = True,
    markup: bool = True
) -> logging.Logger:
    """
    Get or create a Rich-formatted logger.

    Args:
        name (str): Name of the logger. Defaults to "geemlib".
        level (str): Logging level. Defaults to "INFO".
        format (str): Log message format. Defaults to "%(message)s".
        datefmt (str): Date format. Defaults to "[%X]".
        rich_tracebacks (bool): Enable rich tracebacks. Defaults to True.
        markup (bool): Enable markup parsing. Defaults to True.

    Returns:
        logging.Logger: Configured logger instance
    """
    logger = logging.getLogger(name)

    # Only configure the logger if it hasn't been configured before
    if not logger.handlers:
        logger.setLevel(level)

        rich_handler = RichHandler(
            rich_tracebacks=rich_tracebacks,
            markup=markup,
        )
        rich_handler.setFormatter(logging.Formatter(format, datefmt=datefmt))

        logger.addHandler(rich_handler)

    return logger
